@@ -9,6 +9,7 @@ from pathlib import PurePath
 
 import pandas as pd
 from dulwich import porcelain
+from dulwich.client import HTTPUnauthorized
 from dulwich.ignore import IgnoreFilter
 from dulwich.ignore import read_ignore_patterns
 
@@ -21,12 +22,12 @@ data_file_suffixes = {
 gitburl = 'https://github.com/'
 
 class GithubData :
-    def __init__(self ,
-                 source_url ,
-                 public = True ,
-                 user_token_json_path = None) :
+    def __init__(
+            self ,
+            source_url ,
+            user_token_json_path = None
+            ) :
         self.source_url = source_url
-        self.public = public
         self._usr_tok_jsp = user_token_json_path
 
         self.clean_source_url = clean_github_url(source_url)
@@ -50,13 +51,20 @@ class GithubData :
         self.meta_fp = None
 
         self._init_local_path()
+        self._set_data_fps()
+        self.read_json()
 
     @property
-    def local_path(self) :
+    def local_path(
+            self
+            ) :
         return self._local_path
 
     @local_path.setter
-    def local_path(self , local_dir) :
+    def local_path(
+            self ,
+            local_dir
+            ) :
         if local_dir is None :
             self._local_path = Path(self.repo_name)
         else :
@@ -65,14 +73,21 @@ class GithubData :
         if self._local_path.exists() :
             print('Warning: local_path already exists')
 
-    def _init_local_path(self) :
+    def _init_local_path(
+            self
+            ) :
         self.local_path = None
 
-    def _list_ev_thing_in_repo_dir(self) :
+    def _list_ev_thing_in_repo_dir(
+            self
+            ) :
         evt = list(self._local_path.glob('*'))
         return [PurePath(x).relative_to(self._local_path) for x in evt]
 
-    def _remove_ignored_files(self , file_paths) :
+    def _remove_ignored_files(
+            self ,
+            file_paths
+            ) :
         ignore_fp = self._local_path / '.gitignore'
 
         if not ignore_fp.exists() :
@@ -85,20 +100,27 @@ class GithubData :
 
         return [x for x in file_paths if not flt.is_ignored(x)]
 
-    def _stage_evthing_in_repo(self) :
+    def _stage_evthing_in_repo(
+            self
+            ) :
         evt = self._list_ev_thing_in_repo_dir()
         not_ignored = self._remove_ignored_files(evt)
         stg = [str(x) for x in not_ignored]
+        self._repo.add(stg)
         self._repo.stage(stg)
 
-    def _set_defualt_data_suffix(self) :
+    def _set_defualt_data_suffix(
+            self
+            ) :
         for ky in data_file_suffixes.keys() :
             fps = self.ret_sorted_fpns_by_suf(ky)
             if len(fps) >= 1 :
                 self._data_suf = ky
                 break
 
-    def _set_data_fps(self) :
+    def _set_data_fps(
+            self
+            ) :
         self._set_defualt_data_suffix()
 
         if self._data_suf is None :
@@ -111,12 +133,17 @@ class GithubData :
         else :
             self.data_fp = fpns
 
-    def ret_sorted_fpns_by_suf(self , suffix) :
+    def ret_sorted_fpns_by_suf(
+            self ,
+            suffix
+            ) :
         suffix = '.' + suffix if suffix[0] != '.' else suffix
         the_list = list(self._local_path.glob(f'*{suffix}'))
         return sorted(the_list)
 
-    def read_json(self) :
+    def read_json(
+            self
+            ) :
         fps = self.ret_sorted_fpns_by_suf('.json')
         if len(fps) == 0 :
             return None
@@ -131,15 +158,18 @@ class GithubData :
 
         return js
 
-    def _input_cred_usr_tok(self) :
-        usr = input('(skip for default) github username: ')
+    def _input_cred_usr_tok(
+            self
+            ) :
+        usr = input('(enter nothing for same as repo source) github username: ')
         if usr.strip() == '' :
             self._cred_usr = self.user_name
-
         tok = input('token: ')
         self._cred_tok = tok
 
-    def _set_cred_usr_tok(self) :
+    def _set_cred_usr_tok(
+            self
+            ) :
         if self._usr_tok_jsp is not None :
             fp = self._usr_tok_jsp
             self._cred_usr , self._cred_tok = get_usr_tok_from_jsp(fp)
@@ -157,63 +187,68 @@ class GithubData :
 
         self._input_cred_usr_tok()
 
-    def _set_clone_url(self) :
-        if self.public :
-            self._clone_url = self.clean_source_url
-        else :
-            self._set_cred_usr_tok()
-            usr = self._cred_usr
-            tok = self._cred_tok
-            tr = self.user_repo
-            self._clone_url = github_url_wt_credentials(usr , tok , tr)
+    def _set_clone_url(
+            self
+            ) :
+        self._set_cred_usr_tok()
+        usr = self._cred_usr
+        tok = self._cred_tok
+        tr = self.user_repo
+        self._clone_url = github_url_wt_credentials(usr , tok , tr)
 
-    def clone(self , depth = 1) :
-        """
-        Every time excecuted, it re-downloads last version of the reposiroty to local_path.
+    def overwriting_clone(
+            self ,
+            depth = 1
+            ) :
+        """ Every time excecuted, it re-downloads last version of the reposiroty to local_path.
 
         param depth: None for full depth, default = 1 (last version)
-        :return: None
+        return: None
         """
-        if self._local_path.exists() :
+        trgdir = self._local_path
+        if trgdir.exists() :
             self.rmdir()
 
-        self._set_clone_url()
-        url = self._clone_url
-
-        targ_dir = self._local_path
-
-        self._repo = porcelain.clone(url , targ_dir , depth = depth)
+        try :
+            self._clone_url = self.clean_source_url
+            url = self._clone_url
+            self._repo = porcelain.clone(url , trgdir , depth = depth)
+        except HTTPUnauthorized :
+            self._set_clone_url()
+            url = self._clone_url
+            self._repo = porcelain.clone(url , trgdir , depth = depth)
 
         self._set_data_fps()
         self.read_json()
 
-    def _set_commit_url(self , user_token_json_path) :
-        if not self.public :
+    def _set_commit_url(
+            self
+            ) :
+        if self._clone_url != self.clean_source_url :
             self._commit_url = self._clone_url
         else :
-            self._usr_tok_jsp = user_token_json_path
             self._set_cred_usr_tok()
             usr = self._cred_usr
             tok = self._cred_tok
             tr = self.user_repo
             self._commit_url = github_url_wt_credentials(usr , tok , tr)
 
-    def commit_and_push(self ,
-                        message ,
-                        branch = 'main' ,
-                        user_token_json_path = None) :
-        self._set_commit_url(user_token_json_path)
+    def commit_and_push(
+            self ,
+            message ,
+            branch = 'main'
+            ) :
+        self._set_commit_url()
         url = self._commit_url
-
         self._stage_evthing_in_repo()
-
         self._repo.do_commit(message.encode())
-
         porcelain.push(str(self._local_path) , url , branch)
 
-    def read_data(self) :
+    def read_data(
+            self
+            ) :
         if not self._local_path.exists() :
-            self.clone()
+            self.overwriting_clone()
         else :
             self._set_data_fps()
 
@@ -223,10 +258,14 @@ class GithubData :
             else :
                 return pd.read_parquet(self.data_fp)
 
-    def rmdir(self) :
+    def rmdir(
+            self
+            ) :
         shutil.rmtree(self._local_path)
 
-def clean_github_url(github_repo_url) :
+def clean_github_url(
+        github_repo_url
+        ) :
     inp = github_repo_url
 
     inp = inp.replace(gitburl , '')
@@ -238,23 +277,30 @@ def clean_github_url(github_repo_url) :
     urp = urp.split('#')[0]
 
     url = gitburl + urp
-
     return url
 
-def github_url_wt_credentials(user , token , targ_repo) :
+def github_url_wt_credentials(
+        user ,
+        token ,
+        targ_repo
+        ) :
     return f'https://{user}:{token}@github.com/{targ_repo}'
 
-def get_data_from_github(github_repo_url) :
+def get_data_from_github(
+        github_repo_url
+        ) :
     """
     param github_repo_url: url of the GitHub repo
-    :return: pandas.DataFrame
+    return: pandas.DataFrame
     """
     repo = GithubData(github_repo_url)
     df = repo.read_data()
     repo.rmdir()
     return df
 
-def get_usr_tok_from_jsp(jsp) :
+def get_usr_tok_from_jsp(
+        jsp
+        ) :
     with open(jsp , 'r') as fi :
         js = json.load(fi)
     return js['usr'] , js['tok']
@@ -262,7 +308,7 @@ def get_usr_tok_from_jsp(jsp) :
 def get_github_token_pathes() :
     rp_url = 'https://github.com/imahdimir/github-token-path'
     rp = GithubData(rp_url)
-    rp.clone()
+    rp.overwriting_clone()
     js = rp.meta
     op = None
     for pn in js.values() :
@@ -271,4 +317,6 @@ def get_github_token_pathes() :
             op = fp
             break
     rp.rmdir()
-    return op
\ No newline at end of file
+    return op
+
+##
